@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Draw fretboard chord diagrams
 
-our $VERSION = '0.0301';
+our $VERSION = '0.0302';
 
 use Moo;
 use strictures 2;
@@ -239,7 +239,7 @@ Music::FretboardDiagram - Draw fretboard chord diagrams
 
 =head1 VERSION
 
-version 0.0301
+version 0.0302
 
 =head1 SYNOPSIS
 
@@ -274,6 +274,9 @@ version 0.0301
 A C<Music::FretboardDiagram> object draws fretboard chord diagrams including
 neck position and chord name annotations for guitar, ukulele, banjo, etc.
 
+This module outputs PNG image files only.  So for instance, on Linux and Macs
+you will need the libpng-dev library.
+
 =for html <br><img src="https://raw.githubusercontent.com/ology/Music-FretboardDiagram/master/chord-diagram.png"><br>
 
 =head1 ATTRIBUTES
@@ -403,7 +406,8 @@ Construct the B<fretboard> attribute from the B<tuning>.
 
   $dia->draw;
 
-Render the requested chord diagram as a PNG image.
+Render the requested chord diagram as a C<PNG> image.  (Other formats are not
+supported.)
 
 =head1 SEE ALSO
 
